| Title: | Climate Data Integration for Modeling Building Energy Demand |
|---|---|
| Description: | Prepare climate data to be used by building energy demand models. |
| Authors: | Hagen Tockhorn [aut, cre] |
| Maintainer: | Hagen Tockhorn <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.4 |
| Built: | 2026-05-15 08:57:35 UTC |
| Source: | https://github.com/pik-piam/climbed |